==> on_chain-3.0.1.tar.gz: example/lib/example/cardano/provider_example/provider.dart <==
import 'dart:convert';
import 'package:http/http.dart' as http;
import 'package:on_chain/ada/src/provider/blockfrost/core/core.dart';
import 'package:on_chain/ada/src/provider/service/service.dart';

class BlockforestHTTPProvider implements BlockfrostServiceProvider {
  BlockforestHTTPProvider(
      {required this.url,
      this.version = "v0",
      this.projectId,
      http.Client? client,
      this.defaultRequestTimeout = const Duration(seconds: 30)})
      : client = client ?? http.Client();
  @override
  final String url;
  final String version;
  final String? projectId;
  final http.Client client;
  final Duration defaultRequestTimeout;

  @override
  Future<dynamic> get(BlockforestRequestDetails params,
      [Duration? timeout]) async {
    final response =
        await client.get(Uri.parse(params.url(url, version)), headers: {
      'Content-Type': 'application/json',
      "Accept": "application/json",
      if (projectId != null) ...{"project_id": projectId!},
    }).timeout(timeout ?? defaultRequestTimeout);
    final data = json.decode(response.body);
    return data;
  }

  @override
  Future<dynamic> post(BlockforestRequestDetails params,
      [Duration? timeout]) async {
    final response = await client.post(
      Uri.parse(params.url(url, version)),
      headers: {
        "Accept": "application/json",
        if (projectId != null) ...{"project_id": projectId!},
        ...params.header
      },
    ).timeout(timeout ?? defaultRequestTimeout);
    final data = json.decode(response.body);
    return data;
  }
}

==> on_chain-3.2.0.tar.gz: example/lib/example/cardano/provider_example/provider.dart <==
import 'dart:convert';
import 'package:http/http.dart' as http;
import 'package:on_chain/ada/src/provider/blockfrost/core/core.dart';
import 'package:on_chain/ada/src/provider/service/service.dart';

class BlockforestHTTPProvider implements BlockfrostServiceProvider {
  BlockforestHTTPProvider(
      {required this.url,
      this.version = "v0",
      this.projectId,
      http.Client? client,
      this.defaultRequestTimeout = const Duration(seconds: 30)})
      : client = client ?? http.Client();
  @override
  final String url;
  final String version;
  final String? projectId;
  final http.Client client;
  final Duration defaultRequestTimeout;

  @override
  Future<dynamic> get(BlockforestRequestDetails params,
      [Duration? timeout]) async {
    final response =
        await client.get(Uri.parse(params.url(url, version)), headers: {
      'Content-Type': 'application/json',
      "Accept": "application/json",
      if (projectId != null) ...{"project_id": projectId!},
    }).timeout(timeout ?? defaultRequestTimeout);
    final data = json.decode(response.body);
    return data;
  }

  @override
  Future<dynamic> post(BlockforestRequestDetails params,
      [Duration? timeout]) async {
    final response = await client
        .post(Uri.parse(params.url(url, version)),
            headers: {
              "Accept": "application/json",
              if (projectId != null) ...{"project_id": projectId!},
              ...params.header
            },
            body: params.body)
        .timeout(timeout ?? defaultRequestTimeout);
    final data = json.decode(response.body);
    return data;
  }
}
